/** An options object for filtering and output modification */
interface GenerateOptions {
    /**  Regex words must match to have a chance of being randomly chosen */
    contains?: RegExp | string;
    /**
     * A length or range of lengths that a word must match for it to have a
     *  chance of being randomly chosen
     */
    length?: string | number;
    /** Determines the capitalization of the randomly chosen words */
    capitalize?: 'none' | 'first' | 'all';
}
export declare class rword {
    static globalPool: string[];
    static readonly words: string[];
    /** Randomly generates words from the words array. */
    static generate(count?: number, opt?: GenerateOptions): string | string[];
    /** Shuffles words and globalPool arrays. */
    static shuffle(): void;
    /**
     * A simple generator that pulls words from a prefilled global pool. Should
     *  be preferred over `rword.generate()` if custom filters are not needed as
     *  this method can in certain instances be many times faster.
     * @param count - Words to return. Throws error if greater than `10`
     */
    static generateFromPool(count?: number): string | string[];
}
export {};
